@@ -93,6 +93,8 @@ def _do_work_order(
 ):
     zest_result_to_return = None
 
+    # In a new process, reset the _bubble_exceptions
+    zest._bubble_exceptions = False
     zest.reset(disable_shuffle, bypass_skip)
 
     with open_event_stream(output_folder, root_name) as event_stream:
